/* vi: set sw=4 ts=4: */
/*
 * lunar.h
 *
 * This file is part of liblunar.
 *
 * Copyright (C) 2007 - yetist <yetist@gmail.com>.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 * */

#ifndef __LUNAR_H__
#define __LUNAR_H__  1

#ifdef HAVE_CONFIG_H
    #include <config.h>
#endif

#include <lunar/lunar-date.h>

#ifdef ENABLE_GTK
    #include <lunar/lunar-calendar.h>
#endif

#include <lunar/lunar-main.h>

#endif /*__LUNAR_H__ */
